==> org-lsst-ccs-subsystem-airwatch-main-1.0.2-sources.jar: org/lsst/ccs/subsystem/airwatch/main/InstrumentType.java <==
package org.lsst.ccs.subsystem.airwatch.main;

import java.util.Optional;

import java.util.function.Function;

import java.util.stream.Stream;

/**
 * The different kinds of instruments recognized by the subsystem.
 * @author tether
 */
public enum InstrumentType {
    
    /**
     * Lighthouse Worldwide Solutions 3016-like particle counter.
     */
    LIGHTHOUSE("lighthouse", LighthouseInstrument::new),
    
    /**
     * A simulated instrument for testing purposes.
     */
    DUMMY("dummy", DummyInstrument::new);
    
    private final String configName;
    
    private final Function<InstrumentConfig, Instrument> maker;
    
    InstrumentType(String configName, Function<InstrumentConfig, Instrument> maker) {
        this.configName = configName;
        this.maker = maker;
    }
    
    /**
     * Gets the instrument type name as it should appear in configuration data.
     * @return The configuration name.
     */
    public String getConfigName() {return configName;}
    
    /**
     * Makes the right kind of {@code Instrument} objects using {@code InstrumentConfigs}.
     * @param config The configuration information needed to make the new instrument object.
     * @return The new instrument object.
     */
    public Instrument make(InstrumentConfig config) {return maker.apply(config);}
    
    /**
     * Converts a string to one of the instances of this enum. The string, converted to
     * lower case, should match the configuration name of one of the instances.
     * @param name The string to parse.
     * @return A full Optional if success, otherwise an empty one.
     */
    public static Optional<InstrumentType> parse(final String name) {
        return Stream.of(InstrumentType.values())
            .filter(x -> name.equalsIgnoreCase(x.getConfigName()))
            .findAny();
    }
}

==> org-lsst-ccs-subsystem-airwatch-main-1.1.4-sources.jar: org/lsst/ccs/subsystem/airwatch/main/InstrumentType.java <==
package org.lsst.ccs.subsystem.airwatch.main;

import java.util.Optional;

import java.util.function.Function;

import java.util.stream.Stream;

/**
 * The different kinds of instruments recognized by the subsystem.
 * @author tether
 */
public enum InstrumentType {
    
    /**
     * Lighthouse Worldwide Solutions 3016-like particle counter with a direct Modbus connection.
     */
    LIGHTHOUSE_MODBUS("LighthouseModbus", LighthouseModbus::new),

    /**
     * Lighthouse "instrument" which is actually a set of values published by the
     * LMS Express RT program using the OPC protocol.
     */
    LIGHTHOUSE_OPC("LighthouseOPC", LighthouseOPC::new),
    
    /**
     * A simulated instrument for testing purposes.
     */
    DUMMY("dummy", DummyInstrument::new);
    
    private final String configName;
    
    private final Function<InstrumentConfig, Instrument> maker;
    
    InstrumentType(String configName, Function<InstrumentConfig, Instrument> maker) {
        this.configName = configName;
        this.maker = maker;
    }
    
    /**
     * Gets the instrument type name as it should appear in configuration data.
     * @return The configuration name.
     */
    public String getConfigName() {return configName;}
    
    /**
     * Makes the right kind of {@code Instrument} objects using {@code InstrumentConfigs}.
     * @param config The configuration information needed to make the new instrument object.
     * @return The new instrument object.
     */
    public Instrument make(InstrumentConfig config) {return maker.apply(config);}
    
    /**
     * Converts a string to one of the instances of this enum. The string, converted to
     * lower case, should match the configuration name of one of the instances.
     * @param name The string to parse.
     * @return A full Optional if success, otherwise an empty one.
     */
    public static Optional<InstrumentType> parse(final String name) {
        return Stream.of(InstrumentType.values())
            .filter(x -> name.equalsIgnoreCase(x.getConfigName()))
            .findAny();
    }
}
